# Delayed Impact
The [delayed impact simulator](https://arxiv.org/abs/1803.04383) is a simplified
lending scenario based on:

Liu, L., Dean, S., Rolf, E., Simchowitz, M., & Hardt, M. (2018, July). Delayed
Impact of Fair Machine Learning. In International Conference on Machine Learning
(pp. 3156-3164). Chicago.

The intended purpose of the model was to study how static fairness criteria
interact with time-varying indicators of well-being.
